
# Slot: subject


the case (e.g. patient) that has the property

URI: [biolink:case_to_entity_association_mixin_subject](https://w3id.org/biolink/vocab/case_to_entity_association_mixin_subject)


## Domain and Range

[CaseToEntityAssociationMixin](CaseToEntityAssociationMixin.md) &#8594;  <sub>1..1</sub> [Case](Case.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [CaseToEntityAssociationMixin](CaseToEntityAssociationMixin.md)
